@@ -2,7 +2,7 @@
 #include "buffer.h"
 #include "scan.h"
 
-int buffer_get_token(buffer* b,char* x,unsigned int len,const char* charset,unsigned int setlen) {
+int buffer_get_token(buffer* b,unsigned char* x,unsigned long int len,const unsigned char* charset,unsigned long int setlen) {
   int blen;
 
   for (blen=0;blen<len;++blen) {
