@@ -1,7 +1,7 @@
 #include "byte.h"
 #include "buffer.h"
 
-int buffer_getn(buffer* b,char* x,unsigned int len) {
+int buffer_getn(buffer* b,unsigned char* x,unsigned long int len) {
   int blen;
 
   for(blen=0;blen<len;++blen) {
