@@ -21,9 +21,14 @@ void errmsg_iam(const char* who);	/* set argv0 */
 void errmsg_warn(const char* message, ...);
 void errmsg_warnsys(const char* message, ...);
 
+void errmsg_info(const char* message, ...);
+void errmsg_infosys(const char* message, ...);
+
 #define carp(...) errmsg_warn(__VA_ARGS__,0)
 #define carpsys(...) errmsg_warnsys(__VA_ARGS__,0)
-#define die(n,...) { errmsg_warn(__VA_ARGS__,0); exit(n); }
-#define diesys(n,...) { errmsg_warnsys(__VA_ARGS__,0); exit(n); }
+#define die(n,...) do { errmsg_warn(__VA_ARGS__,0); exit(n); } while (0)
+#define diesys(n,...) do { errmsg_warnsys(__VA_ARGS__,0); exit(n); } while (0)
+#define msg(...) errmsg_info(__VA_ARGS__,0);
+#define msgsys(...) errmsg_infosys(__VA_ARGS__,0);
 
 #endif
