@@ -2,8 +2,8 @@
 
 unsigned int fmt_long(char *dest,long int i) {
   if (i<0) {
-    if (dest) *dest='-';
-    return fmt_ulong(dest+1,-i);
+    if (dest) *dest++='-';
+    return fmt_ulong(dest,-i)+1;
   } else
     return fmt_ulong(dest,i);
 }
