@@ -1,11 +1,19 @@
 #ifndef IP6_H
 #define IP6_H
 
-extern unsigned int scan_ip6(const char *src,char *ip);
-extern unsigned int fmt_ip6(char *dest,const char *ip);
+#include "byte.h"
+#include "uint32.h"
 
-extern unsigned int scan_ip6_flat(const char *src,char *);
-extern unsigned int fmt_ip6_flat(char *dest,const char *);
+unsigned int scan_ip6(const char* src,char* ip);
+unsigned int fmt_ip6(char* dest,const char* ip);
+unsigned int fmt_ip6c(char* dest,const char* ip);
+
+unsigned int scan_ip6if(const char* src,char* ip,uint32* scope_id);
+unsigned int fmt_ip6if(char* dest,const char* ip,uint32 scope_id);
+unsigned int fmt_ip6ifc(char* dest,const char* ip,uint32 scope_id);
+
+unsigned int scan_ip6_flat(const char *src,char *);
+unsigned int fmt_ip6_flat(char *dest,const char *);
 
 /*
  ip6 address syntax: (h = hex digit), no leading '0' required
