@@ -2,10 +2,11 @@
 
 unsigned int scan_long(const char *src,long *dest) {
   register const char *tmp;
-  register int l;
+  register long int l;
   register unsigned char c;
   int neg;
-  tmp=src; l=0; neg=0;
+  int ok;
+  tmp=src; l=0; ok=neg=0;
   switch (*tmp) {
   case '-': neg=1;
   case '+': ++tmp;
@@ -13,7 +14,8 @@ unsigned int scan_long(const char *src,long *dest) {
   while ((c=*tmp-'0')<10) {
     l=l*10+c;
     ++tmp;
+    ok=1;
   }
-  *dest=(neg?-l:l);
+  if (ok) *dest=(neg?-l:l);
   return tmp-src;
 }
