@@ -1,7 +1,10 @@
 #include <sys/types.h>
 #include <sys/param.h>
+#ifndef __MINGW32__
 #include <sys/socket.h>
 #include <netinet/in.h>
+#endif
+#include "windoze.h"
 #include "byte.h"
 #include "socket.h"
 
@@ -12,5 +15,5 @@ int socket_send4(int s,const char *buf,unsigned int len,const char ip[4],uint16
   si.sin_family = AF_INET;
   uint16_pack_big((char*) &si.sin_port,port);
   *((uint32*)&si.sin_addr) = *((uint32*)ip);
-  return sendto(s,buf,len,0,(struct sockaddr *) &si,sizeof si);
+  return winsock2errno(sendto(s,buf,len,0,(struct sockaddr *) &si,sizeof si));
 }
