@@ -1,6 +1,9 @@
 #include <sys/types.h>
+#ifndef __MINGW32__
 #include <sys/socket.h>
 #include <netinet/in.h>
+#endif
+#include "windoze.h"
 #include <errno.h>
 #include "haveip6.h"
 #include "socket.h"
@@ -14,8 +17,9 @@ int socket_tcp6(void)
 #ifdef LIBC_HAS_IP6
   int s;
 
+  __winsock_init();
   if (noipv6) goto compat;
-  s = socket(PF_INET6,SOCK_STREAM,0);
+  s = winsock2errno(socket(PF_INET6,SOCK_STREAM,0));
   if (s == -1) {
     if (errno == EINVAL || errno == EAFNOSUPPORT) {
 compat:
@@ -25,6 +29,12 @@ compat:
     } else
     return -1;
   }
+#ifdef IPV6_V6ONLY
+  {
+    int zero=0;
+    winsock2errno(setsockopt(s,IPPROTO_IPV6,IPV6_V6ONLY,(void*)&zero,sizeof(zero)));
+  }
+#endif
   return s;
 #else
   return socket_tcp4();
