@@ -1,7 +1,7 @@
 #include "stralloc.h"
 #include "fmt.h"
 
-int stralloc_catlong0(stralloc *sa,signed long in,unsigned int n) {
+int stralloc_catlong0(stralloc *sa,signed long int in,unsigned long int n) {
   if (stralloc_readyplus(sa,fmt_minus(0,in)+fmt_ulong0(0,in,n))) {
     sa->len+=fmt_minus(sa->s+sa->len,in);
     sa->len+=fmt_ulong0(sa->s+sa->len,in>=0?in:-in,n);
